@@ -13,16 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging as std_logging
 import pickle
 import re
 import sys
 
 import memcache
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import six
 from six.moves.urllib import parse
 
-from stackalytics.openstack.common import log as logging
 from stackalytics.processor import config
 from stackalytics.processor import utils
 
@@ -84,7 +85,7 @@ def import_data(memcached_inst, fd):
 def get_repo_keys(memcached_inst):
     for repo in (memcached_inst.get('repos') or []):
         uri = repo['uri']
-        branches = set(['master'])
+        branches = {repo.get('default_branch', 'master')}
         for release in repo.get('releases'):
             if 'branch' in release:
                 branches.add(release['branch'])
@@ -130,7 +131,8 @@ def export_data(memcached_inst, fd):
         user = memcached_inst.get('user:%s' % user_seq)
         if user:
             if user.get('user_id'):
-                pickle.dump(('user:%s' % user['user_id'], user), fd)
+                pickle.dump((('user:%s' % user['user_id']).encode('utf8'),
+                             user), fd)
             if user.get('launchpad_id'):
                 pickle.dump(('user:%s' % user['launchpad_id'], user), fd)
             if user.get('gerrit_id'):
@@ -138,7 +140,7 @@ def export_data(memcached_inst, fd):
             if user.get('member_id'):
                 pickle.dump(('user:member:%s' % user['member_id'], user), fd)
             for email in user.get('emails') or []:
-                pickle.dump(('user:%s' % email, user), fd)
+                pickle.dump((('user:%s' % email).encode('utf8'), user), fd)
 
 
 def _connect_to_memcached(uri):
@@ -157,10 +159,13 @@ def main():
     conf.register_cli_opts(OPTS)
     conf.register_opts(config.OPTS)
     conf.register_opts(OPTS)
-    conf()
+    logging.register_options(conf)
+    logging.set_defaults()
+    conf(project='stackalytics')
 
-    logging.setup('stackalytics')
+    logging.setup(conf, 'stackalytics')
     LOG.info('Logging enabled')
+    conf.log_opt_values(LOG, std_logging.DEBUG)
 
     memcached_inst = _connect_to_memcached(cfg.CONF.runtime_storage_uri)
 
